**********
* Immigration and Redistribution
* Alesina, Miano, Stantcheva
* RESTUD

* This files prepares and exports the data for Figures 2 to 7 and 9 in the folder Out/Figures_data. To produce the final figures the data should be imported in R using the codes Figures2_7.rmd and Figure9.rmd
**********

clear all

* Specify directory of the replication package
global dir "/Users/armandomiano/Dropbox/AMS_Redistribution/Data/Survey_Data/Replication RESTUD sharing"
cd "$dir"

* Declare output sub-directory

global outdir "Out/Figures_data"

* Load the data

use "Data/survey_analysis.dta", clear

* Countries included in the analysis
global countries "US UK DE FR IT SE"


* Generate flags - To ensure answers quality
gen flag_1=0
gen flag_2=0

* Keep only those with flag 1 and flag 2 equal to zero

bysort country treatment_recod: egen min_duration = pctile(duration), p(2)
bysort country treatment_recod: egen max_duration = pctile(duration), p(98)

replace flag_1=1 if duration<min_duration
replace flag_2=1 if duration>max_duration

* Drop respondents in bottom and top 2% of distribution of time spent on the survey
keep if flag_1==0 & flag_2==0

*Drop variable used to exclude inattentive respondents
drop flag_1 flag_2 min_duration max_duration

* Add data on actual natives and immigrants statistics and generate misperceptions *

do "Do/misperceptions.do"

* Gen variables to be plotted *

* Dummy = 1 if Mohammad receives more on net from the state (either receives more transfers and pays same or less taxes or receives same transfers but pays less taxes)
gen moh_more=(Moh_transfers<3 & Moh_tax>2)
replace moh_more=1 if Moh_transfers==3 & Moh_tax>3
replace moh_more=. if Moh_tax==. | Moh_transfers==.
la var moh_more "Mohammad receives more transfers and/or pays less taxes than John"
label val moh_more binary

* Transfers
gen imm_tra_twice_more=(transfers_imm==11 |transfers_imm==12 |transfers_imm==13)
la var imm_tra_twice_more "Immigrants receive tiwice as many transfers as natives or more"
replace imm_tra_twice_more=. if transfers_imm==.
label val imm_tra_twice_more binary

****************
* Gen additional controls *
****************

* Immigrant parent
gen immigrant_parent=(q_parent_same==2)
replace immigrant_parent=. if q_parent_same==.
label var immigrant_parent "Immigrant parent"
label val immigrant_parent binary


* Gen Left-right variables *
* Based on vote or voting intentions
gen left=(party_voted==4 | party_voted==5)
replace left=. if party_voted==. | party_voted==6 | party_voted==0
gen right=(party_voted==1 | party_voted==2)
replace right=. if party_voted==. | party_voted==6 | party_voted==0
gen center=(party_voted==3)
replace center=. if party_voted==. | party_voted==6 | party_voted==0

label var left "Left-wing"
label var right "Right-wing"
label var center "Center"

foreach i in left right center{
label val `i' binary
}

* Young
gen young=(age<45)
label var young "Age 18 to 45"
label val young binary

* Gender
gen male=(sex==1)
label var male "Male"
label val male binary

* Top income
gen top_income=0
foreach x in $countries{
su household_income if country=="`x'", d
replace top_income=1 if household_income>r(p75) & country=="`x'"
}
label var top_income "High Income"
label val top_income binary

* Sector dummy
label var sector_dummy "High intensity sector"


* Gen variables for high immigration sectors, with low/high educ
gen sector_dummy_h=sector_dummy*university_degree
gen sector_dummy_l=sector_dummy*(1-university_degree)


**********************
* Keep only control group *

keep if control==1

*********************

* Gen group variables

gen var_1= left
gen var_2= male
gen var_3= young
gen var_4= immigrant_parent
gen var_5= top_income
gen var_6= university_degree
gen var_7= sector_dummy_h
gen var_8= sector_dummy_l


************************
* Figure 2 - Share of immigrants
************************

* Misperception by group

**** Share of immigrants *
global vars mis_share_foreign
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "High Income" 10 "Low Income" 11 "College" 12 "No College" 13 "H.Imm. S.&No Coll." 14 "H. Imm. S.&Coll." 15 "Not H. Imm. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
        gen ub_bY = .
        gen lb_bY = .
		gen bN = .
        gen ub_bN = .
        gen lb_bN = .		
		gen n=_n
		
	
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
	export delimited "$outdir/figure_2_r_data.csv", replace		
	
	restore
	
	
*** Perceptions by country ***

gen var_perc = perc_share_foreign

gen var_real = share_foreign


*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
ci means var_real if country=="`x'", level(95)
local m_real`x' = r(mean)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_real = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		replace m_real=`m_real`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}
	
	export delimited "$outdir/figure_2_l_data.csv", replace
				
restore	

drop var_perc var_real

************************
* Figure 3, Panel A -- Share of Muslim immigrants
************************

**** Share of muslim
global vars mis_share_mu
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "Rich" 10 "Not Rich" 11 "College" 12 "Not College" 13 "H.Sect.&L.Ed" 14 "H.Sect.&H.Ed" 15 "No H. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
        gen ub_bY = .
        gen lb_bY = .
		gen bN = .
        gen ub_bN = .
        gen lb_bN = .		
		gen n=_n
		
	
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
	export delimited "$outdir/figure_3_a_r_data.csv", replace
			
	restore
	
** By Country **

gen var_perc = perc_share_mu

gen var_real = share_muslim

*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
ci means var_real if country=="`x'", level(95)
local m_real`x' = r(mean)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_real = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		replace m_real=`m_real`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}
				
	export delimited "$outdir/figure_3_a_l_data.csv", replace
				
restore	

drop var_perc var_real


************************
* Figure 3, Panel B -- Share of Christian immigrants
************************


* Misperception by group

**** Share of christian *
global vars mis_share_ch
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "Rich" 10 "Not Rich" 11 "College" 12 "Not College" 13 "H.Sect.&L.Ed" 14 "H.Sect.&H.Ed" 15 "No H. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
        gen ub_bY = .
        gen lb_bY = .
		gen bN = .
        gen ub_bN = .
        gen lb_bN = .		
		gen n=_n
		
	
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
	export delimited "$outdir/figure_3_b_r_data.csv", replace
			
	restore



*** By country

gen var_perc = perc_share_ch

gen var_real = share_christian


*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
ci means var_real if country=="`x'", level(95)
local m_real`x' = r(mean)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_real = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		replace m_real=`m_real`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}
				
		export delimited "$outdir/figure_3_b_l_data.csv", replace
				
restore	

drop var_perc var_real

*************************
* Figure 4, Immigrants' and natives' economic circumstances
* Panel A -- Share of High Educated
***********************


* By group *

global vars mis_higheduc_imm
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
qui su `var' if var_`q'==1, detail
local b2Y_`q' = r(p50)
local ub2_bY_`q' = r(p75)
local lb2_bY_`q' = r(p25)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
qui su `var' if var_`q'==0, detail
local b2N_`q' = r(p50)
local ub2_bN_`q' = r(p75)
local lb2_bN_`q' = r(p25)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
qui su `var' if var_1==1 & center!=1, detail
local b2Y_1 = r(p50)
local ub2_bY_1 = r(p75)
local lb2_bY_1 = r(p25)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)
qui su `var' if var_1==0 & center!=1, detail
local b2N_1 = r(p50)
local ub2_bN_1 = r(p75)
local lb2_bN_1 = r(p25)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
qui su `var' if sector_dummy==0 , detail
local b2N_7 = r(p50)
local b2N_8 = r(p50)
local ub2_bN_7 = r(p75)
local lb2_bN_7 = r(p25)
local ub2_bN_8 = r(p75)
local lb2_bN_8 = r(p25)
}

global vars mis_higheduc_nat
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bNY_`q' = r(mean)
local ub_bNY_`q' = r(ub)
local lb_bNY_`q' = r(lb)
qui su `var' if var_`q'==1, detail
local b2NY_`q' = r(p50)
local ub2_bNY_`q' = r(p75)
local lb2_bNY_`q' = r(p25)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bNN_`q' = r(mean)
local ub_bNN_`q' = r(ub)
local lb_bNN_`q' = r(lb)
qui su `var' if var_`q'==0, detail
local b2NN_`q' = r(p50)
local ub2_bNN_`q' = r(p75)
local lb2_bNN_`q' = r(p25)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bNY_1 = r(mean)
local ub_bNY_1 = r(ub)
local lb_bNY_1 = r(lb)
qui su `var' if var_1==1 & center!=1, detail
local b2NY_1 = r(p50)
local ub2_bNY_1 = r(p75)
local lb2_bNY_1 = r(p25)
ci means `var' if var_1==0 & center!=1, level(95)
local bNN_1 = r(mean)
local ub_bNN_1 = r(ub)
local lb_bNN_1 = r(lb)
qui su `var' if var_1==0 & center!=1, detail
local b2NN_1 = r(p50)
local ub2_bNN_1 = r(p75)
local lb2_bNN_1 = r(p25)

ci means `var' if sector_dummy==0 , level(95)
local bNN_7 = r(mean)
local ub_bNN_7 = r(ub)
local lb_bNN_7 = r(lb)
local bNN_8 = r(mean)
local ub_bNN_8 = r(ub)
local lb_bNN_8 = r(lb)
qui su `var' if sector_dummy==0 , detail
local b2NN_7 = r(p50)
local b2NN_8 = r(p50)
local ub2_bNN_7 = r(p75)
local lb2_bNN_7 = r(p25)
local ub2_bNN_8 = r(p75)
local lb2_bNN_8 = r(p25)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "Rich" 10 "Not Rich" 11 "College" 12 "Not College" 13 "H.Sect.&L.Ed" 14 "H.Sect.&H.Ed" 15 "No H. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
		gen bNY = .
        gen ub_bY = .
        gen lb_bY = .
		gen ub_bNY = .
        gen lb_bNY = .
		gen bN = .
		gen bNN = .
        gen ub_bN = .
        gen lb_bN = .
		gen ub_bNN = .
        gen lb_bNN = .		
		gen n=_n
		
		
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 3
	    forvalues i=1(1)6 {	
		replace bNY=`bNY_`i'' if n==`q'
		replace ub_bNY=`ub_bNY_`i'' if n==`q'
		replace lb_bNY=`lb_bNY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bNN=`bNN_`i'' if n==`q'
		replace ub_bNN=`ub_bNN_`i'' if n==`q'
		replace lb_bNN=`lb_bNN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
		replace bNY=`bNY_8' if n==39
		replace ub_bNY=`ub_bNY_8' if n==39
		replace lb_bNY=`lb_bNY_8' if n==39
		
		replace bNN=`bNY_7' if n==42
		replace ub_bNN=`ub_bNY_7' if n==42
		replace lb_bNN=`lb_bNY_7' if n==42
		
		replace bNN=`bNN_7' if n==45
		replace ub_bNN=`ub_bNN_7' if n==45
		replace lb_bNN=`lb_bNN_7' if n==45

	export delimited "$outdir/figure_4_a_r_data.csv", replace
			
restore


*** Perceptions by country ***

gen var_perc = mis_higheduc_imm

gen var_nat = mis_higheduc_nat


*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
ci means var_nat if country=="`x'", level(95)
local m_nat`x' = r(mean)
local lb_nat`x' = r(lb)
local ub_nat`x' = r(ub)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_nat = .
		gen lb_nat = .
		gen ub_nat = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		replace m_nat=`m_nat`x'' if n==`q'
		replace lb_nat=`lb_nat`x'' if n==`q'
		replace ub_nat=`ub_nat`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}
	
	export delimited "$outdir/figure_4_a_l_data.csv", replace
				
restore	

drop var_perc var_nat
			

*************************
* Figure 4, Panel B -- Unemployment
***********************



global vars mis_unemp_imm
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
qui su `var' if var_`q'==1, detail
local b2Y_`q' = r(p50)
local ub2_bY_`q' = r(p75)
local lb2_bY_`q' = r(p25)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
qui su `var' if var_`q'==0, detail
local b2N_`q' = r(p50)
local ub2_bN_`q' = r(p75)
local lb2_bN_`q' = r(p25)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
qui su `var' if var_1==1 & center!=1, detail
local b2Y_1 = r(p50)
local ub2_bY_1 = r(p75)
local lb2_bY_1 = r(p25)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)
qui su `var' if var_1==0 & center!=1, detail
local b2N_1 = r(p50)
local ub2_bN_1 = r(p75)
local lb2_bN_1 = r(p25)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
qui su `var' if sector_dummy==0 , detail
local b2N_7 = r(p50)
local b2N_8 = r(p50)
local ub2_bN_7 = r(p75)
local lb2_bN_7 = r(p25)
local ub2_bN_8 = r(p75)
local lb2_bN_8 = r(p25)
}

global vars mis_unemp_nat
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bNY_`q' = r(mean)
local ub_bNY_`q' = r(ub)
local lb_bNY_`q' = r(lb)
qui su `var' if var_`q'==1, detail
local b2NY_`q' = r(p50)
local ub2_bNY_`q' = r(p75)
local lb2_bNY_`q' = r(p25)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bNN_`q' = r(mean)
local ub_bNN_`q' = r(ub)
local lb_bNN_`q' = r(lb)
qui su `var' if var_`q'==0, detail
local b2NN_`q' = r(p50)
local ub2_bNN_`q' = r(p75)
local lb2_bNN_`q' = r(p25)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bNY_1 = r(mean)
local ub_bNY_1 = r(ub)
local lb_bNY_1 = r(lb)
qui su `var' if var_1==1 & center!=1, detail
local b2NY_1 = r(p50)
local ub2_bNY_1 = r(p75)
local lb2_bNY_1 = r(p25)
ci means `var' if var_1==0 & center!=1, level(95)
local bNN_1 = r(mean)
local ub_bNN_1 = r(ub)
local lb_bNN_1 = r(lb)
qui su `var' if var_1==0 & center!=1, detail
local b2NN_1 = r(p50)
local ub2_bNN_1 = r(p75)
local lb2_bNN_1 = r(p25)

ci means `var' if sector_dummy==0 , level(95)
local bNN_7 = r(mean)
local ub_bNN_7 = r(ub)
local lb_bNN_7 = r(lb)
local bNN_8 = r(mean)
local ub_bNN_8 = r(ub)
local lb_bNN_8 = r(lb)
qui su `var' if sector_dummy==0 , detail
local b2NN_7 = r(p50)
local b2NN_8 = r(p50)
local ub2_bNN_7 = r(p75)
local lb2_bNN_7 = r(p25)
local ub2_bNN_8 = r(p75)
local lb2_bNN_8 = r(p25)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "Rich" 10 "Not Rich" 11 "College" 12 "Not College" 13 "H.Sect.&L.Ed" 14 "H.Sect.&H.Ed" 15 "No H. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
		gen bNY = .
        gen ub_bY = .
        gen lb_bY = .
		gen ub_bNY = .
        gen lb_bNY = .
		gen bN = .
		gen bNN = .
        gen ub_bN = .
        gen lb_bN = .
		gen ub_bNN = .
        gen lb_bNN = .		
		gen n=_n
		
		
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 3
	    forvalues i=1(1)6 {	
		replace bNY=`bNY_`i'' if n==`q'
		replace ub_bNY=`ub_bNY_`i'' if n==`q'
		replace lb_bNY=`lb_bNY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bNN=`bNN_`i'' if n==`q'
		replace ub_bNN=`ub_bNN_`i'' if n==`q'
		replace lb_bNN=`lb_bNN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
		replace bNY=`bNY_8' if n==39
		replace ub_bNY=`ub_bNY_8' if n==39
		replace lb_bNY=`lb_bNY_8' if n==39
		
		replace bNN=`bNY_7' if n==42
		replace ub_bNN=`ub_bNY_7' if n==42
		replace lb_bNN=`lb_bNY_7' if n==42
		
		replace bNN=`bNN_7' if n==45
		replace ub_bNN=`ub_bNN_7' if n==45
		replace lb_bNN=`lb_bNN_7' if n==45

	export delimited "$outdir/figure_4_b_r_data.csv", replace
					
restore

*** Perceptions by country ***

gen var_perc = mis_unemp_imm

gen var_nat = mis_unemp_nat


*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
ci means var_nat if country=="`x'", level(95)
local m_nat`x' = r(mean)
local lb_nat`x' = r(lb)
local ub_nat`x' = r(ub)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_nat = .
		gen lb_nat = .
		gen ub_nat = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		replace m_nat=`m_nat`x'' if n==`q'
		replace lb_nat=`lb_nat`x'' if n==`q'
		replace ub_nat=`ub_nat`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}
	
	export delimited "$outdir/figure_4_b_l_data.csv", replace
				
restore	

drop var_perc var_nat

************************
* Figure 5, Immigrants' Work Effort
* Panel A -- Effort - Poor
************************

* By group *

* Lack of Effort reason poor *
global vars effort_poor
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "Rich" 10 "Not Rich" 11 "College" 12 "Not College" 13 "H.Sect.&L.Ed" 14 "H.Sect.&H.Ed" 15 "No H. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
        gen ub_bY = .
        gen lb_bY = .
		gen bN = .
        gen ub_bN = .
        gen lb_bN = .		
		gen n=_n
		
	
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
	export delimited "$outdir/figure_5_a_r_data.csv", replace
	
			
	restore
	
* By country *

gen var_perc = effort_poor


*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
*ci means var_real if country=="`x'", level(95)
*local m_real`x' = r(mean)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_real = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		*replace m_real=`m_real`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}
		
		* Add averages from Alesina, Stantcheva and Teso (2018)
		replace m_real=0.458694398 if n==30
		replace m_real=0.366271406 if n==25
		replace m_real=0.234680578 if n==20
		replace m_real=0.137414962 if n==15
		replace m_real=0.323788553 if n==5
		
	export delimited "$outdir/figure_5_a_l_data.csv", replace	
				
restore	

drop var_perc

*************************
* Figure 5, Panel B -- Effort - Rich
*********************

* By group

**** Effort reason rich *
global vars effort_rich
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "Rich" 10 "Not Rich" 11 "College" 12 "Not College" 13 "H.Sect.&L.Ed" 14 "H.Sect.&H.Ed" 15 "No H. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
        gen ub_bY = .
        gen lb_bY = .
		gen bN = .
        gen ub_bN = .
        gen lb_bN = .		
		gen n=_n
		
	
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
	export delimited "$outdir/figure_5_b_r_data.csv", replace	
			
	restore
	
	
* By country

gen var_perc = effort_rich

*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
*ci means var_real if country=="`x'", level(95)
*local m_real`x' = r(mean)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_real = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		*replace m_real=`m_real`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}
		
		*US
		replace m_real=0.391681105 if n==30
		*UK
		replace m_real=0.312252969 if n==25
		*FR
		replace m_real=0.305084735 if n==20
		*IT
		replace m_real=0.16870749 if n==15
		*SE
		replace m_real=0.383259922 if n==5
		
		
	export delimited "$outdir/figure_5_b_l_data.csv", replace
restore	

drop var_perc


************************
* Figure 6, Are Immigrants The Beneficiaries of Redistribution?
* Panel A -- An immigtant gets twice as much as a native
************************

**** Immigrants get twice as much as natives or more *

* By group

global vars imm_tra_twice_more
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "Rich" 10 "Not Rich" 11 "College" 12 "Not College" 13 "H.Sect.&L.Ed" 14 "H.Sect.&H.Ed" 15 "No H. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
        gen ub_bY = .
        gen lb_bY = .
		gen bN = .
        gen ub_bN = .
        gen lb_bN = .		
		gen n=_n
		
	
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
	export delimited "$outdir/figure_6_a_r_data.csv", replace
			
	restore
	
* By country

gen var_perc = imm_tra_twice_more

*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
*ci means var_real if country=="`x'", level(95)
*local m_real`x' = r(mean)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_real = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		*replace m_real=`m_real`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}	
		
	export delimited "$outdir/figure_6_a_l_data.csv", replace
					
restore	

drop var_perc


************************
* Figure 6, Panel B -- Conditional Transfers (Mohammad vs. John)
************************

**** Mohammad question *

* By group

global vars moh_more
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "Rich" 10 "Not Rich" 11 "College" 12 "Not College" 13 "H.Sect.&L.Ed" 14 "H.Sect.&H.Ed" 15 "No H. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
        gen ub_bY = .
        gen lb_bY = .
		gen bN = .
        gen ub_bN = .
        gen lb_bN = .		
		gen n=_n
		
	
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
	export delimited "$outdir/figure_6_b_r_data.csv", replace
			
	restore

* By country *

gen var_perc = moh_more

*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
*ci means var_real if country=="`x'", level(95)
*local m_real`x' = r(mean)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_real = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		*replace m_real=`m_real`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}	
		
	export delimited "$outdir/figure_6_b_l_data.csv", replace
					
restore	

drop var_perc

************************
* Figure 7 -- Poverty
************************

* By group *

global vars mis_poverty_imm
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bY_`q' = r(mean)
local ub_bY_`q' = r(ub)
local lb_bY_`q' = r(lb)
qui su `var' if var_`q'==1, detail
local b2Y_`q' = r(p50)
local ub2_bY_`q' = r(p75)
local lb2_bY_`q' = r(p25)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bN_`q' = r(mean)
local ub_bN_`q' = r(ub)
local lb_bN_`q' = r(lb)
qui su `var' if var_`q'==0, detail
local b2N_`q' = r(p50)
local ub2_bN_`q' = r(p75)
local lb2_bN_`q' = r(p25)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bY_1 = r(mean)
local ub_bY_1 = r(ub)
local lb_bY_1 = r(lb)
qui su `var' if var_1==1 & center!=1, detail
local b2Y_1 = r(p50)
local ub2_bY_1 = r(p75)
local lb2_bY_1 = r(p25)
ci means `var' if var_1==0 & center!=1, level(95)
local bN_1 = r(mean)
local ub_bN_1 = r(ub)
local lb_bN_1 = r(lb)
qui su `var' if var_1==0 & center!=1, detail
local b2N_1 = r(p50)
local ub2_bN_1 = r(p75)
local lb2_bN_1 = r(p25)

ci means `var' if sector_dummy==0 , level(95)
local bN_7 = r(mean)
local ub_bN_7 = r(ub)
local lb_bN_7 = r(lb)
local bN_8 = r(mean)
local ub_bN_8 = r(ub)
local lb_bN_8 = r(lb)
qui su `var' if sector_dummy==0 , detail
local b2N_7 = r(p50)
local b2N_8 = r(p50)
local ub2_bN_7 = r(p75)
local lb2_bN_7 = r(p25)
local ub2_bN_8 = r(p75)
local lb2_bN_8 = r(p25)
}

global vars mis_poverty_nat
foreach var in $vars{
forvalues q=2(1)8 {
ci means `var' if var_`q'==1, level(95)
local bNY_`q' = r(mean)
local ub_bNY_`q' = r(ub)
local lb_bNY_`q' = r(lb)
qui su `var' if var_`q'==1, detail
local b2NY_`q' = r(p50)
local ub2_bNY_`q' = r(p75)
local lb2_bNY_`q' = r(p25)
}
forvalues q=2(1)8 {
ci means `var' if var_`q'==0, level(95)
local bNN_`q' = r(mean)
local ub_bNN_`q' = r(ub)
local lb_bNN_`q' = r(lb)
qui su `var' if var_`q'==0, detail
local b2NN_`q' = r(p50)
local ub2_bNN_`q' = r(p75)
local lb2_bNN_`q' = r(p25)
}
ci means `var' if var_1==1 & center!=1, level(95)
local bNY_1 = r(mean)
local ub_bNY_1 = r(ub)
local lb_bNY_1 = r(lb)
qui su `var' if var_1==1 & center!=1, detail
local b2NY_1 = r(p50)
local ub2_bNY_1 = r(p75)
local lb2_bNY_1 = r(p25)
ci means `var' if var_1==0 & center!=1, level(95)
local bNN_1 = r(mean)
local ub_bNN_1 = r(ub)
local lb_bNN_1 = r(lb)
qui su `var' if var_1==0 & center!=1, detail
local b2NN_1 = r(p50)
local ub2_bNN_1 = r(p75)
local lb2_bNN_1 = r(p25)

ci means `var' if sector_dummy==0 , level(95)
local bNN_7 = r(mean)
local ub_bNN_7 = r(ub)
local lb_bNN_7 = r(lb)
local bNN_8 = r(mean)
local ub_bNN_8 = r(ub)
local lb_bNN_8 = r(lb)
qui su `var' if sector_dummy==0 , detail
local b2NN_7 = r(p50)
local b2NN_8 = r(p50)
local ub2_bNN_7 = r(p75)
local lb2_bNN_7 = r(p25)
local ub2_bNN_8 = r(p75)
local lb2_bNN_8 = r(p25)
}
preserve
        clear
        set obs 46
        egen t = seq()
		label define quintile 1 "Left-Wing" 2 "Right-Wing" 3 "Male" 4 "Female" 5 "Age 18-45" 6 "Age 46-69" 7 "Imm. Parent" 8 "No Imm. Parent" 9 "Rich" 10 "Not Rich" 11 "College" 12 "Not College" 13 "H.Sect.&L.Ed" 14 "H.Sect.&H.Ed" 15 "No H. Sect."
		label values t quintile
		replace t=t/3
				
        gen bY = .
		gen bNY = .
        gen ub_bY = .
        gen lb_bY = .
		gen ub_bNY = .
        gen lb_bNY = .
		gen bN = .
		gen bNN = .
        gen ub_bN = .
        gen lb_bN = .
		gen ub_bNN = .
        gen lb_bNN = .		
		gen n=_n
		
		
		local q = 3
	    forvalues i=1(1)6 {	
		replace bY=`bY_`i'' if n==`q'
		replace ub_bY=`ub_bY_`i'' if n==`q'
		replace lb_bY=`lb_bY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 3
	    forvalues i=1(1)6 {	
		replace bNY=`bNY_`i'' if n==`q'
		replace ub_bNY=`ub_bNY_`i'' if n==`q'
		replace lb_bNY=`lb_bNY_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bN=`bN_`i'' if n==`q'
		replace ub_bN=`ub_bN_`i'' if n==`q'
		replace lb_bN=`lb_bN_`i'' if n==`q'
		local q = `q' + 6
		}
		
		local q = 6
		forvalues i=1(1)6 {
		replace bNN=`bNN_`i'' if n==`q'
		replace ub_bNN=`ub_bNN_`i'' if n==`q'
		replace lb_bNN=`lb_bNN_`i'' if n==`q'
		local q = `q' + 6
		}
		
	
		replace bY=`bY_8' if n==39
		replace ub_bY=`ub_bY_8' if n==39
		replace lb_bY=`lb_bY_8' if n==39
		
		replace bN=`bY_7' if n==42
		replace ub_bN=`ub_bY_7' if n==42
		replace lb_bN=`lb_bY_7' if n==42
		
		replace bN=`bN_7' if n==45
		replace ub_bN=`ub_bN_7' if n==45
		replace lb_bN=`lb_bN_7' if n==45
		
		replace bNY=`bNY_8' if n==39
		replace ub_bNY=`ub_bNY_8' if n==39
		replace lb_bNY=`lb_bNY_8' if n==39
		
		replace bNN=`bNY_7' if n==42
		replace ub_bNN=`ub_bNY_7' if n==42
		replace lb_bNN=`lb_bNY_7' if n==42
		
		replace bNN=`bNN_7' if n==45
		replace ub_bNN=`ub_bNN_7' if n==45
		replace lb_bNN=`lb_bNN_7' if n==45

	export delimited "$outdir/figure_7_r_data.csv", replace
							
restore

* By country *

gen var_perc = mis_poverty_imm

gen var_nat = mis_poverty_nat


*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
ci means var_nat if country=="`x'", level(95)
local m_nat`x' = r(mean)
local lb_nat`x' = r(lb)
local ub_nat`x' = r(ub)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_nat = .
		gen lb_nat = .
		gen ub_nat = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		replace m_nat=`m_nat`x'' if n==`q'
		replace lb_nat=`lb_nat`x'' if n==`q'
		replace ub_nat=`ub_nat`x'' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}
	
	export delimited "$outdir/figure_7_l_data.csv", replace
				
restore	

drop var_perc var_nat


********************
* Figure 9 - Share of first and second gen immigrants
*******************


* By Country graph

gen var_perc = perc_share_foreign

gen var_real = share_foreign

gen var_real_2 = share_foreign2



*** Means of variables ***
foreach x in US UK IT FR SE DE {	
ci means var_perc if country=="`x'", level(95)
*storing mean and confidence interval for perceived data
local m_perc`x' = r(mean)
local lb_perc`x' = r(lb)
local ub_perc`x' = r(ub)
ci means var_real if country=="`x'", level(95)
local m_real`x' = r(mean)
ci means var_real_2 if country=="`x'", level(95)
local m_real`x'_2 = r(mean)
qui su var_perc if country=="`x'", detail
local md_perc`x' = r(p50)
local p25`x' = r(p25)
local p75`x' = r(p75)
}


preserve
        clear
        set obs 31
        egen t = seq()
		label define var 1 "Sweden"  2 "Germany" 3 "Italy" 4 "France" 5 "UK" 6 "US"
		label values t var
		replace t=t/5
		
		gen m_perc = .
		gen md_perc = .
		gen lb_perc = .
		gen ub_perc = .
		gen m_real = .
		gen m_real_2 = .
		gen p25 = .
		gen p75 = .
		
		gen n=_n
		
		local q = 5
		foreach x in SE DE IT FR UK US {
		replace m_perc=`m_perc`x'' if n==`q'
		replace md_perc=`md_perc`x'' if n==`q'
		replace lb_perc=`lb_perc`x'' if n==`q'
		replace ub_perc=`ub_perc`x'' if n==`q'
		replace m_real=`m_real`x'' if n==`q'
		replace m_real_2=`m_real`x'_2' if n==`q'
		replace p25=`p25`x'' if n==`q'
		replace p75=`p75`x'' if n==`q'
		local q = `q' + 5
		}
		
		
	export delimited "$outdir/figure_9_data.csv", replace
	

			
							
restore	

drop var_perc var_real var_real_2

