**********
* Immigration and Redistribution
* Alesina, Miano, Stantcheva
* RESTUD

* Table 1
* You should install the command frmttable before running this dofile -- type "search frmttable" and select sg97_5
**********

clear all

* Specify directory of the replication package
global dir "/Users/armandomiano/Dropbox/AMS_Redistribution/Data/Survey_Data/Replication RESTUD sharing"
cd "$dir"

* Declare output sub-directory
global outdir "Out/Tables"

* Load the data
use "Data/survey_analysis.dta", clear

* Generate country dummies
gen US=(country=="US")
label var US "Answered the survey for the United States"
gen UK=(country=="UK")
label var UK "Answered the survey for the United Kingdom"
gen Italy=(country=="IT")
label var Italy "Answered the survey for Italy"
gen Sweden=(country=="SE")
label var Sweden "Answered the survey for Sweden"
gen Germany=(country=="DE")
label var Germany "Answered the survey for Germany"
gen France=(country=="FR")
label var France "Answered the survey for France"

foreach i in US UK Italy Sweden Germany France{
label val `i' binary
}

* Generate flags - To ensure answers quality

* Time spent on the survey
gen flag_1=0
gen flag_2=0

bysort country treatment_recod: egen min_duration = pctile(duration), p(2)
bysort country treatment_recod: egen max_duration = pctile(duration), p(98)

replace flag_1=1 if duration<min_duration
replace flag_2=1 if duration>max_duration

* Time spent on videos
global videos t1 t2 t3 

foreach q in $videos{
	
bysort country: egen max_time_`q'= pctile(time_`q'), p(98)
}

foreach q in $videos{

gen flag_time_max_`q'=(time_`q'> max_time_`q')
replace flag_time_max_`q'=. if time_`q'==.

}


* Drop respondents that have spent too little or too much time on the survey (bottom/top 2%)
keep if flag_1==0 & flag_2==0


* Drop respondents who have spent too much time on the videos (top 2%)
foreach q in $videos{

drop if flag_time_max_`q'==1

}

* Drop the variables used to exclude inattentive respondents
drop flag_1 flag_2 min_duration max_duration max_time_t1 max_time_t2 max_time_t3 flag_time_max_t1 flag_time_max_t2 flag_time_max_t3

* Gen variables *

* Gender
gen male=(sex==1)
label var male "Is a male"
label val male binary

* Age brackets
gen age_1=(age>=18 & age<=29)
label var age_1 "Is between 18 and 29"
gen age_2=(age>=30 & age<=39)
label var age_2 "Is between 30 and 39"
gen age_3=(age>=40 & age<=49)
label var age_3 "Is between 40 and 49"
gen age_4=(age>=50 & age<=59)
label var age_4 "Is between 50 and 59"
gen age_5=(age>=60)
label var age_5 "Is 60 or above"

foreach i in 1 2 3 4 5{
label val age_`i' binary
}

* Income brackets
gen inc_bracket_1=0
label var inc_bracket_1 "Is in the first income bracket"
gen inc_bracket_2=0
label var inc_bracket_2 "Is in the second income bracket"
gen inc_bracket_3=0
label var inc_bracket_3 "Is in the third income bracket"
gen inc_bracket_4=0
label var inc_bracket_4 "Is in the last income bracket"

	* US
	replace inc_bracket_1=1 if household_income<4 & US==1
	replace inc_bracket_2=1 if (household_income==4 | household_income==5) & US==1
	replace inc_bracket_3=1 if(household_income==6 | household_income==7) & US==1
	replace inc_bracket_4=1 if household_income>7 & US==1
	
	* UK
	replace inc_bracket_1=1 if income_q_UK==1 | income_q_UK==4 
	replace inc_bracket_2=1 if income_q_UK==5 
	replace inc_bracket_3=1 if income_q_UK==6
	replace inc_bracket_4=1 if income_q_UK==7
	
	* FR
	replace inc_bracket_1=1 if income_q_FR==1 | income_q_FR==4 
	replace inc_bracket_2=1 if income_q_FR==5 
	replace inc_bracket_3=1 if income_q_FR==3
	replace inc_bracket_4=1 if income_q_FR==2 | income_q_FR==8
	
	* IT
	replace inc_bracket_1=1 if income_q_IT==1 
	replace inc_bracket_2=1 if income_q_IT==4 
	replace inc_bracket_3=1 if income_q_IT==5
	replace inc_bracket_4=1 if income_q_IT==3 | income_q_IT==2
	
	* DE
	replace inc_bracket_1=1 if income_q_DE==1 | income_q_DE==4 
	replace inc_bracket_2=1 if income_q_DE==5 | income_q_DE==3
	replace inc_bracket_3=1 if income_q_DE==2
	replace inc_bracket_4=1 if income_q_DE==8 | income_q_DE==9
	
	*SE
	replace inc_bracket_1=1 if income_q_SE==1 
	replace inc_bracket_2=1 if income_q_SE==5 
	replace inc_bracket_3=1 if income_q_SE==4
	replace inc_bracket_4=1 if income_q_SE==3

foreach i in 1 2 3 4{
label val inc_bracket_`i' binary
}	
	
* Married dummy (=0 if "other")
gen married=(marital_status==2)
label var married "Is married"
label val married binary

* Gen employed
gen employed=(employment<4)
replace employed=. if employment==.
label var employed "Is employed"
label val employed binary

* Gen unemployed
gen unemployed=(employment==4)
replace unemployed=. if employment==.
label var unemployed "Is unemployed"
label val unemployed binary



******** Table 1: to check representativeness of the sample ******

cap mata drop A

* Gender
foreach x in US UK France Italy Germany Sweden {
su male if `x'==1
local male`x' : display %5.2f `r(mean)'
}
matrix A=(`maleUS', 0.49,`maleUK', 0.48,`maleFrance', 0.49,`maleItaly', 0.50, `maleGermany', 0.49,  `maleSweden', 0.50)

* Age
foreach x in US UK France Italy Germany Sweden {
su age_1 if `x'==1
local age_1`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`age_1US', 0.24,`age_1UK', 0.26,`age_1France', 0.23,`age_1Italy', 0.19, `age_1Germany', 0.22, `age_1Sweden', 0.24)
matrix A=A\B
foreach x in US UK France Italy Germany Sweden {
su age_2 if `x'==1
local age_2`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`age_2US', 0.20,`age_2UK', 0.19,`age_2France', 0.20,`age_2Italy', 0.22,`age_2Germany', 0.18, `age_2Sweden', 0.19)
matrix A=A\B
foreach x in US UK France Italy Germany Sweden {
su age_3 if `x'==1
local age_3`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`age_3US', 0.19,`age_3UK', 0.21,`age_3France', 0.21,`age_3Italy', 0.23, `age_3Germany', 0.20,`age_3Sweden', 0.21)
matrix A=A\B
foreach x in US UK France Italy Germany Sweden {
su age_4 if `x'==1
local age_4`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`age_4US', 0.20,`age_4UK', 0.18,`age_4France', 0.20,`age_4Italy', 0.19, `age_4Germany', 0.23,`age_4Sweden', 0.18)
matrix A=A\B
foreach x in US UK France Italy Germany Sweden {
su age_5 if `x'==1
local age_5`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`age_5US', 0.17,`age_5UK', 0.16,`age_5France', 0.15,`age_5Italy', 0.17, `age_5Germany', 0.17,`age_5Sweden', 0.18)
matrix A=A\B

* Income
foreach x in US UK France Italy Germany Sweden {
su inc_bracket_1 if `x'==1
local inc_bracket_1`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`inc_bracket_1US', 0.16,`inc_bracket_1UK', 0.31,`inc_bracket_1France', 0.32,`inc_bracket_1Italy', 0.27, `inc_bracket_1Germany', 0.26,`inc_bracket_1Sweden', 0.33)
matrix A=A\B
foreach x in US UK France Italy Germany Sweden {
su inc_bracket_2 if `x'==1
local inc_bracket_2`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`inc_bracket_2US', 0.19,`inc_bracket_2UK', 0.35,`inc_bracket_2France', 0.30,`inc_bracket_2Italy',  0.28, `inc_bracket_2Germany', 0.29,`inc_bracket_2Sweden', 0.29)
matrix A=A\B
foreach x in US UK France Italy Germany Sweden {
su inc_bracket_3 if `x'==1
local inc_bracket_3`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`inc_bracket_3US', 0.22,`inc_bracket_3UK', 0.11,`inc_bracket_3France', 0.14,`inc_bracket_3Italy', 0.19, `inc_bracket_3Germany', 0.23,`inc_bracket_3Sweden', 0.22)
matrix A=A\B
foreach x in US UK France Italy Germany Sweden {
su inc_bracket_4 if `x'==1
local inc_bracket_4`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`inc_bracket_4US', 0.43,`inc_bracket_4UK', 0.23,`inc_bracket_4France', 0.24,`inc_bracket_4Italy', 0.26, `inc_bracket_4Germany', 0.22,`inc_bracket_4Sweden', 0.17)
matrix A=A\B


* Married
foreach x in US UK France Italy Germany Sweden {
su married if `x'==1
local married`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`marriedUS', 0.49,`marriedUK', 0.41,`marriedFrance', 0.46,`marriedItaly', 0.46, `marriedGermany', 0.46, `marriedSweden', 0.33)
matrix A=A\B


* Employed
foreach x in US UK France Italy Germany Sweden {
su employed if `x'==1
local employed`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`employedUS', 0.70,`employedUK', 0.74,`employedFrance', 0.65,`employedItaly', 0.57, `employedGermany', 0.75, `employedSweden', 0.77)
matrix A=A\B

* Unemployed
foreach x in US UK France Italy Germany Sweden {
su unemployed if `x'==1
local unemployed`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`unemployedUS', 0.05,`unemployedUK', 0.05,`unemployedFrance', 0.09,`unemployedItaly', 0.11, `unemployedGermany', 0.04,`unemployedSweden', 0.05)
matrix A=A\B

* University degree
foreach x in US UK France Italy Germany Sweden {
su university_degree if `x'==1
local university`x' : display %5.2f `r(mean)'
}
cap mata drop B
matrix B=(`universityUS', 0.41,`universityUK', 0.36,`universityFrance', 0.31,`universityItaly', 0.16, `universityGermany', 0.25, `universitySweden', 0.36)
matrix A=A\B

mat rownames A=male age_1 age_2 age_3 age_4 age_5 inc_bracket_1 inc_bracket_2 inc_bracket_3 inc_bracket_4 married employed unemployed university

frmttable using "$outdir/summary_stats_sample_by_country_final.tex", statmat(A) tex fragment replace ///
		ctitle("",US,"", UK,"", France,"", Italy,"", Germany, "", Sweden,""\"", Sample, Pop, Sample, Pop,Sample, Pop,Sample, Pop,Sample, Pop,Sample, Pop\"", "(1)", "(2)", "(3)", "(4)", "(5)", "(6)", "(7)", "(8)", "(9)", "(10)", "(11)", "(12)") ///
		rtitle(Male\ 18-29 y.o.\30-39 y.o.\40-49 y.o.\50-59 y.o.\60-69 y.o.\Income Bracket 1 \Income Bracket 2 \Income Bracket 3 \Income Bracket 4\ Married\ Employed\ Unemployed\ College) ///
		multicol(1,2,2;1,4,2;1,6,2;1,8,2;1,10,2;1,12,2) hlines(110100000000000001) noce
