**********
* Immigration and Redistribution
* Alesina, Miano, Stantcheva
* RESTUD

* This file generates the variables for the actual statistics on immigrants and non-immigrants (natives) and computes misperceptions (perceived - actual)
* See the Appendix for all the details on the sources and computations of the actual statistics
**********

** Share of foreign-born ***
gen share_foreign=.
la var share_foreign "Actual share of foreign born"
replace share_foreign=14.8 if country=="DE"
replace share_foreign=12.2 if country=="FR"
replace share_foreign=10 if country=="IT"
replace share_foreign=13.4 if country=="UK"
replace share_foreign=10 if country=="US"
replace share_foreign=17.6 if country=="SE"

** Share of second-generation immigrants ***
gen share_second_gen=.
la var share_second_gen "Actual share of second-gen. immigrants"
replace share_second_gen=7.4 if country=="DE"
replace share_second_gen=11 if country=="FR"
replace share_second_gen=2.4 if country=="IT"
replace share_second_gen=9.2 if country=="UK"
replace share_second_gen=15.4 if country=="US" // Also including 3.5 illegal immigrants
replace share_second_gen=13 if country=="SE"

**********
* Share of immigrants from each area
gen share_NA=.
la var share_NA "Actual share imm. from North America"
gen share_LA=.
la var share_LA "Actual share imm. from Latin America"
gen share_WE=.
la var share_WE "Actual share imm. from Western Europe"
gen share_EE=.
la var share_EE "Actual share imm. from Eastern Europe"
gen share_NAF=.
la var share_NAF "Actual share imm. from North Africa"
gen share_SA=.
la var share_SA "Actual share imm. from Sub-Saharan Africa"
gen share_ME=.
la var share_ME "Actual share imm. from Middle East"
gen share_A=.
la var share_A "Actual share imm. from Asia"
gen share_O=.
la var share_O "Actual share imm. from Oceania"

* United States
replace share_NA=2.3 if country=="US"
replace share_LA=42.3 if country=="US"
replace share_WE=7.7 if country=="US"
replace share_EE=6.1 if country=="US"
replace share_NAF=0.3 if country=="US"
replace share_SA=4.8 if country=="US"
replace share_ME=4.1 if country=="US"
replace share_A=32.1 if country=="US"
replace share_O=0.7 if country=="US"

* UK
replace share_NA=2.3 if country=="UK"
replace share_LA=3.9 if country=="UK"
replace share_WE=19.0 if country=="UK"
replace share_EE=20.0 if country=="UK"
replace share_NAF=0.9 if country=="UK"
replace share_SA=16.0 if country=="UK"
replace share_ME=5.1 if country=="UK"
replace share_A=30.1 if country=="UK"
replace share_O=2.28 if country=="UK"

* Italy
replace share_NA=0.9 if country=="IT"
replace share_LA=9.1 if country=="IT"
replace share_WE=14.3 if country=="IT"
replace share_EE=38.1 if country=="IT"
replace share_NAF=10.2 if country=="IT"
replace share_SA=8.2 if country=="IT"
replace share_ME=2.9 if country=="IT"
replace share_A=15.9 if country=="IT"
replace share_O=0.4 if country=="IT"

* France
replace share_NA=1 if country=="FR"
replace share_LA=3.4 if country=="FR"
replace share_WE=29.3 if country=="FR"
replace share_EE=5.2 if country=="FR"
replace share_NAF=35.3 if country=="FR"
replace share_SA=13.1 if country=="FR"
replace share_ME=5.6 if country=="FR"
replace share_A=7.3 if country=="FR"
replace share_O=0.2 if country=="FR"

* Germany
replace share_NA=1.1 if country=="DE"
replace share_LA=3.2 if country=="DE"
replace share_WE=14.9 if country=="DE"
replace share_EE=42.6 if country=="DE"
replace share_NAF=1.5 if country=="DE"
replace share_SA=2.3 if country=="DE"
replace share_ME=17.3 if country=="DE"
replace share_A=15.9 if country=="DE"
replace share_O=0.1 if country=="DE"

* Sweden
replace share_NA=1.4 if country=="SE"
replace share_LA=5.5 if country=="SE"
replace share_WE=23.6 if country=="SE"
replace share_EE=22.2 if country=="SE"
replace share_NAF=1.2 if country=="SE"
replace share_SA=9.1 if country=="SE"
replace share_ME=23.8 if country=="SE"
replace share_A=12.4 if country=="SE"
replace share_O=0.31 if country=="SE"

*************

* Share of immigrants - Religion
gen share_christian=.
gen share_muslim=.

label var share_muslim "Actual Share Muslims"

label var share_christian "Actual Share Christians"


* United States
replace share_christian=61 if country=="US"
replace share_muslim=10 if country=="US"

* UK
replace share_christian=58 if country=="UK"
replace share_muslim=23 if country=="UK"

* France
replace share_christian=43 if country=="FR"
replace share_muslim=48 if country=="FR"

* Italy
replace share_christian=57 if country=="IT"
replace share_muslim=33 if country=="IT"

* Germany
replace share_christian=51 if country=="DE"
replace share_muslim=30 if country=="DE"

* Sweden
replace share_christian=61 if country=="SE"
replace share_muslim=27 if country=="SE"

* Immigrants' unemployment rate
gen unemp_imm=.
la var unemp_imm "Actual immigrant's unemployment rate"
replace unemp_imm=6.9	if country=="DE"
replace unemp_imm=16.6	if country=="FR"
replace unemp_imm=14.7	if country=="IT"
replace unemp_imm=5.7	if country=="UK"
replace unemp_imm=5.5	if country=="US"
replace unemp_imm=16.1	if country=="SE"

* Highly educated immigrats
gen higheduc_imm=.
la var higheduc_imm "Actual share of highly educated immigrants"
replace higheduc_imm=22.3 if country=="DE"
replace higheduc_imm=28.8 if country=="FR"
replace higheduc_imm=11.7 if country=="IT"
replace higheduc_imm=48.8 if country=="UK"
replace higheduc_imm=41.4 if country=="US"
replace higheduc_imm=37.9 if country=="SE"

* Low educated immigrats
gen loweduc_imm=.
la var loweduc_imm "Actual share of low educated immigrants"
replace loweduc_imm=35.1 if country=="DE"
replace loweduc_imm=39.1 if country=="FR"
replace loweduc_imm=49.1 if country=="IT"
replace loweduc_imm=16.6 if country=="UK"
replace loweduc_imm=22.0 if country=="US"
replace loweduc_imm=33.7 if country=="SE"

* Immigrants' poverty rate
gen poverty_imm=.
la var poverty_imm "Actual immigrants' poverty rate"
replace poverty_imm=20.5 if country=="DE"
replace poverty_imm=23.8 if country=="FR"
replace poverty_imm=34.9 if country=="IT"
replace poverty_imm=19 if country=="UK"
replace poverty_imm=13.6 if country=="US"
replace poverty_imm=29.8 if country=="SE"

****
* Natives' unemployment rate *** 
gen unemp_nat=.
la var unemp_nat "Actual natives' unemployment rate"
replace unemp_nat=3.8	if country=="DE"
replace unemp_nat=9.1	if country=="FR"
replace unemp_nat=11.2	if country=="IT"
replace unemp_nat=4.9	if country=="UK"
replace unemp_nat=5.2	if country=="US"
replace unemp_nat=5.1	if country=="SE"

* Highly educated natives
gen higheduc_nat=.
la var higheduc_nat "Actual share of highly educated natives"
replace higheduc_nat=24.9 if country=="DE"
replace higheduc_nat=31.2 if country=="FR"
replace higheduc_nat=16.3 if country=="IT"
replace higheduc_nat=36 if country=="UK"
replace higheduc_nat=40.8 if country=="US"
replace higheduc_nat=34.6 if country=="SE"

* Low educated natives
gen loweduc_nat=.
la var loweduc_nat "Actual share of low educated natives"
replace loweduc_nat=16.3 if country=="DE"
replace loweduc_nat=23.4 if country=="FR"
replace loweduc_nat=40.4 if country=="IT"
replace loweduc_nat=21.3 if country=="UK"
replace loweduc_nat=11.9 if country=="US"
replace loweduc_nat=17.6 if country=="SE"

* Natives' poverty rate
gen poverty_nat=.
la var poverty_nat "Actual natives' poverty rate"
replace poverty_nat=16.3 if country=="DE"
replace poverty_nat=10.7 if country=="FR"
replace poverty_nat=17.5 if country=="IT"
replace poverty_nat=14.5 if country=="UK"
replace poverty_nat=10.5 if country=="US"
replace poverty_nat=12 if country=="SE"



* Gen misperception variables (guessed - real --> negative for understatement, positive for overstatement) *

* Share, origin, religion of immigrants
foreach g in foreign NA LA WE EE NAF SA ME A O ch mu{
	gen mis_share_`g' = perc_share_`g' - share_`g'
}

* Unemployment, education, poverty of immigrants and natives

foreach g in imm nat{
	foreach s in unemp higheduc loweduc poverty{
		gen mis_`s'_`g' = perc_`s'_`g' - `s'_`g'
	}
}

gen mis_unemp_imm_nn=perc_unemp_imm-unemp_imm
gen mis_higheduc_imm_nn=perc_higheduc_imm-higheduc_imm
gen mis_loweduc_imm_nn=perc_loweduc_imm-loweduc_imm
gen mis_poverty_imm_nn=perc_poverty_imm-poverty_imm

* Grouped origins

	* Middle East + North Africa
	gen mis_share_ME_NAF = mis_share_ME + mis_share_NAF

	* North America + Western and Eastern Europe
	gen mis_share_NA_WE_EE = mis_share_NA + mis_share_WE + mis_share_EE
	
	* Europe
	gen mis_share_E = mis_share_WE + mis_share_EE
	gen perc_share_E = perc_share_WE + perc_share_EE
	
	* Africa
	gen mis_share_AF = mis_share_NAF + mis_share_SA
	gen perc_share_AF = perc_share_NAF + perc_share_SA
	
	* Asia
	gen mis_share_AS = mis_share_A + mis_share_ME
	gen perc_share_AS = perc_share_A + perc_share_ME

* Gen misperception relative to first and second generation immigrants
gen share_foreign2= share_foreign + share_second_gen

gen mis_share_foreign2 = perc_share_foreign - share_foreign2

*Relabel variables
label var mis_share_foreign "Misperception of the share of immigrants"
label var mis_share_NA "Misperception of the share of immigrants from North America"
label var mis_share_LA "Misperception of the share of immigrants from Latin America"
label var mis_share_WE "Misperception of the share of immigrants from Western Europe"
label var mis_share_EE "Misperception of the share of immigrants from Eastern Europe"
label var mis_share_NAF "Misperception of the share of immigrants from North Africa"
label var mis_share_SA "Misperception of the share of immigrants from Sub-saharian Africa"
label var mis_share_ME "Misperception of the share of immigrants from Middle East"
label var mis_share_A "Misperception of the share of immigrants from Asia"
label var mis_share_O "Misperception of the share of immigrants from Oceania"
label var mis_share_ch "Misperception of the share of christian immigrants"
label var mis_share_mu "Misperception of the share of muslim immigrants"
label var mis_unemp_imm "Misperception of the share of unemployed immigrants"
label var mis_higheduc_imm "Misperception of the share of high-educated immigrants"
label var mis_loweduc_imm "Misperception of the share of low-educated immigrants"
label var mis_poverty_imm "Misperception of the share of immigrants living below the poverty threshold"
label var mis_unemp_nat "Misperception of the share of unemployed natives"
label var mis_higheduc_nat "Misperception of the share of high-educated natives"
label var mis_loweduc_nat "Misperception of the share of low-educated natives"
label var mis_poverty_nat "Misperception of the share of natives living below the poverty threshold"
label var mis_share_ME_NAF "Misperception of the share of immigrants from Middle East and North Africa"
label var mis_share_NA_WE_EE "Misperception of the share of immigrants from North America, Western and Eastern Europe"
label var mis_share_E "Misperception of the share of immigrants from Europe"
label var perc_share_E "Perceived share of immigrants from Europe"
label var mis_share_AF "Misperception of the share of immigrants from Africa"
label var perc_share_AF "Perceived share of immigrants from Africa"
label var mis_share_AS "Misperception of the share of immigrants from Asia and Middle East"
label var perc_share_AS "Perceived share of immigrants from Asia and Middle East"
label var share_foreign2 "Actual share of immigrants from first and second generations"
label var mis_share_foreign2 "Misperception of the actual share of immigrants from first and second generations"
label var mis_unemp_imm_nn "Misperception of the number of unemployed immigrants"
label var mis_higheduc_imm_nn "Misperception of the number of high-educated immigrants"
label var mis_loweduc_imm_nn "Misperception of the number of low-educated immigrants"
label var mis_poverty_imm_nn "Misperception of the number of immigrants under the poverty threshold"


